#
# spec file for package qqc2-desktop-style
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           qqc2-desktop-style
Version:        5.116.1
%global _kf5_version 5.116.0
Release:        1.7
Summary:        A Qt Quick Controls 2 Style for Desktop UIs
License:        GPL-2.0-or-later
URL:            https://www.kde.org
Source:         qqc2-desktop-style-%{version}.tar.xz
%if %{with released}
Source1:        qqc2-desktop-style-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  cmake(KF5Config) >= %{_kf5_version}
BuildRequires:  cmake(KF5ConfigWidgets) >= %{_kf5_version}
BuildRequires:  cmake(KF5IconThemes) >= %{_kf5_version}
BuildRequires:  cmake(KF5Kirigami2) >= %{_kf5_version}
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Gui) >= %{qt5_version}
BuildRequires:  cmake(Qt5LinguistTools) >= %{qt5_version}
BuildRequires:  cmake(Qt5Network) >= %{qt5_version}
BuildRequires:  cmake(Qt5Quick) >= %{qt5_version}
BuildRequires:  cmake(Qt5QuickControls2) >= %{qt5_version}
BuildRequires:  cmake(Qt5Svg) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}
# Make sure the required libqt5-qtquickcontrols2 package is usable
# See https://bugs.kde.org/413829#c3
%requires_eq    libqt5-qtquickcontrols2
# plasma5-workspace sets up the env variables so that this theme
# is picked by default. It still works fine without it (no requires),
# but looks better with it. By itself plasma5-workspace does not use
# it (yet), so only install it with libqt5-qtquickcontrols2.
Supplements:    (plasma5-workspace and libqt5-qtquickcontrols2)
# For KUA users
Provides:       plasma5-qqc2-style = %{version}
Obsoletes:      plasma5-qqc2-style < %{version}

%description
A Qt Quick Controls 2 style engine that uses the desktop style
to draw controls with QStyle.

%package devel
Summary:        Development Files for Qt Quick Controls 2 Desktop Style
Requires:       %{name} = %{version}

%description devel
This file contains cmake files to be used by projects that depend on
qqc2-desktop-style.
Usually not needed as it is only a runtime dependency.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --all-name --with-qt

%files
%license LICENSES/*
%dir %{_kf5_plugindir}/kf5/kirigami/
%dir %{_kf5_qmldir}/org/
%dir %{_kf5_qmldir}/org/kde/
%{_kf5_plugindir}/kf5/kirigami/org.kde.desktop.so
%{_kf5_qmldir}/QtQuick/Controls.2/org.kde.desktop/
%{_kf5_qmldir}/org/kde/qqc2desktopstyle/

%files devel
%{_kf5_libdir}/cmake/KF5QQC2DesktopStyle/
# Legacy alias with typo...
%{_kf5_libdir}/cmake/KF5QQC2DeskopStyle/

%files lang -f %{name}.lang

%changelog
* Wed May 22 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.1
- Changes since 5.116.0:
  * Extract translations into qqc2desktopstyle_qt5.pot
  * Really fix the translation file
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- Changes since 5.115.0:
  * Localization support
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- No code change since 5.112.0
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- Changes since 5.109.0:
  * Don't connect the same PanelView to the same PlasmaDesktopTheme N times
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Don't create Sonnet.Settings if not needed
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * Don't attempt to sync colors when application is shutting down
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- Changes since 5.104.0:
  * CheckIndicator: Allow exclusive buttons to be detected via their ButtonGroup (kde#467390)
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * ProgressBar: Pause indeterminate animation when invisible
  * Added flat combobox without outline unless hovered
  * TextField: Fix password-protection code from affecting normal text fields
  * Drawer: Fix RTL by copying sizing code from upstream Default style
  * Drawer: Use simpler sizing expressions from upstream Default style
  * Don't check for selectByMouse on a non-existent root for TextArea
  * use again the palette coming from Kirigami.Theme (kde#465054)
  * Only enable TextArea context menu when able to select by mouse
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- Too many changes since 5.102.0, only listing bugfixes:
  * RadioButton: Add support for icons, just like in CheckBox (kde#442986)
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * kquickstyleitem fix clazy warning clazy-qstring-arg
  * CheckBox/RadioButton/Switch: update implicit sizing code
  * CheckBox/RadioButton/Switch: center align indicators when no content
  * CheckBox/RadioButton/Switch: align indicators with 1st text line
  * Button/ToolButton: allow menu arrows to be added by Accessible.role
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * TextArea: allow touch scrolling even when tablet mode is off
  * Redraw KQuickStyleItem when DPR changes
  * Switch: Improve background contrast when in unchecked state
  * styleitem: Don't destroy and recreate the style on every instance creation
  * Fix blurry controls in QQuickWidget
  * DislogButtonBox: Fix url value comparison with non-strict ==
  * switch: Improve it
  * ToolTip: Do not show tooltips without text
  * BusyIndicator: Synchronize to implementation in PlasmaComponents3
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * Never time out tooltip while its control is still hovered
  * TextField: Use effectiveHorizontalAlignment without extra mirroring
    for placeholder
  * Add Qt6 windows CI support
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * ToolTip: Don't strip ampersands from HTML entities
  * Grammar & typo in README.md
  * Also check for controlRoot.size > 0 (kde#458486)
  * ToolTip: use Text.Wrap, not Text.WordWrap (kde#459331)
  * ToolButton: Do not layout for the icon when it's not set (kde#459470)
  * ProgressBar: Add TODO KF6, since we can't remove the workaround now
  * Add fade in/out animations to ToolTips
  * SpinBox: Flip left/right padding for styles with indicators on the sides
  * SpinBox: Avoid explicit horizontalAlignment in TextField for better RTL
  * SpinBox: Remove assignment which is never read
  * SpinBox: Reset activeSubControls when neither of indicators are active (kde#459004)
  * SpinBox: Let hover events propagate through TextField to the control (kde#459004)
  * SpinBox: Reformat QML for better code style and clarity
  * SpinBox: AlignLeft by default
  * SpinBox: Use implicit size based on the max value
  * SpinBox: move onTextEdited to contentItem, check acceptableInput
  * SpinBox: update imports
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Explicit binding for visible (kde#458486)
  * Make DelayButton look like Spectacle's ProgressButton
  * Add FreeBSD Qt6 CI support
  * Add FIXME about ToolTip instances with child items that use anchors
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * Install style as a regular QML for Qt6
  * ToolTip: Sync to PC3: Strip out ampersands
  * ProgressBar,Slider: Adapt great precision to the harsh reality (kde#455339)
  * Fix QQC2 MenuBar theme. (kde#456729)
  * properly reset the cursorshape (kde#456911)
  * Use QApplication::font with respective widget class
  * Wrap checkbox label
  * ToolTip: wrap text for long tooltips
  * TextArea,TextField: Remove not referenced id from background style item
  * TextField: Disable Undo for password fields, including its context menu
  * Tests: Add manual test for progress bars and sliders
  * Remove dynamic QQC2 version selection
  * Clean up code of manual tests, add missing license headers
  * Fix: url types (like icon.source) are QVariant without length property
  * Nit: reformat long expressions
  * Menu: Fix wrong pixel metric being requested for verticalPadding
  * ProgressBar: Drop layout direction hack
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * Require passing tests for the CI to pass
  * iterate only over visible children in menu
  * Avoid a crash with kscreenlocker_greet or any other QGuiApplication
  * Make StackView obey the global animation speed setting (kde#395324)
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * Buttons: Press F to pay respects
  * DelayButton: Fix invalid id references in transition/animation
  * ProgressBar,Slider: Draw position smoothly with greater precision
  * MenuItem: Remove redundant check
  * Clean up whitespaces and JavaScript: Fix broken syntax
  * Clean up whitespaces and JavaScript
  * ProgressBar: Fix rendering of visual position when `from` is non-zero
  * ProgressBar: Replace hardcoded redraw interval with frame-based animations
  * RoundButton: Fix expression block may return nothing (undefined)
  * ScrollView: Stop passing down `enabled` property to the ScrollBars explicitly
  * ScrollView: Drop support for nullable ScrollBars
  * ScrollView: Remove id from a scrollbar
  * ScrollView: Fix aged comment
  * ScrollView: Fix whitespace
  * port away from Qt smart pointers where possible
  * ComboBox: Use qualified ListView.view attached property in delegate
  * ComboBox: Remove workaround for `editable` property from Qt 5.7 times
  * ComboBox: Use rect type for rect property
  * proper fix for the previous commit
  * Fix overlapping scrollbar (kde#453958)
  * Relayout the scrollbar when non interactive
  * Remove code that was only used with Qt <5.8
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * Add windows CI
  * Remove infoChanged signal from KQuickStyleItem
  * Replace connect to self in KQuickStyleItem with direct method calls
  * Recalculate metrics when tablet mode changes
  * Fix use of a no longer existing id
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Do not make space for invisible items in menus
  * TextFieldContextMenu: Make menu separator invisible when its preceding
    items are too
  * KQuickStyleItem: use control mirrored property if available
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Thicken menus on transient touch as well as being in Tablet Mode
  * PlasmaDesktopTheme: ensure we initialise the colours
  * Fix typo
  * PlasmaDesktopTheme: Do not compute the colors for invisible items
  * PlasmaDesktopTheme: Do not call syncColors after syncWindow
  * Menu: use hmargin and vmargin from QStyle
  * Support displaying icons in ItemDelegate (kde#425867)
  * fix checkbox position for CheckDelegate
  * Drop lib prefix when building for Windows
  * KQuickStyleItem: Simplify the updatePolish
  * Use correct DBus signal for listening for font changes
  * Use raw pointer instead of QPointer to track watchers
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Avoid needlessly reading font settings
  * StyleItem: emit signal on style changes
  * Add Linux Qt6 CI
  * install plugins in kf<version>
  * take icon width into account
  * adapt width of combobox to its content (kde#403153)
  * Theme placeholderTextColor
  * Make menu items taller in Tablet Mode
  * Fix find_package
  * Remove QStyle::State_Horizontal when it's not horizontal
  * Adapt build system for building against qt6
  * Slider: handle scrolling (kde#417211)
  * Use upstream scroll implementations for Combobox and SpinBox
  * Use metrics from Breeze for menu items (kde#447289)
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * TextFieldContextMenu: Fix menu not opening
  * Fix binding loop in Spinbox (kde#446354)
  * Add A SpinBox test
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * Fix syntax highlighting
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Too many changes since 5.87.0, only listing bugfixes:
  * Don't change MenuItem's arrow's color when selected (kde#443453)
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
  * Properly get the path from a QUrl
  * Port away from devicePixelRatio
  * MenuSeparator: fix height being wrong, rewrite whole file to be more correct
  * Button, ToolButton: improve implicit sizing, correctly set default button state
  * Use more process-working-symbolic icon for busy spinner
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Too many changes since 5.85.0, only listing bugfixes:
  * Fix combobox popup in RTL mode (kde#441178)
  * Vertically center slider (kde#410672)
  * ScrollBar: less scuffed implementation of reading from QStyle (kde#418327)
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Introduce MenuBar implementation
  * Make sure raised is initialised
  * Do not create an extra KIconLoader just for custom palettes
  * Use flat instead of raised for flat buttons and toolbuttons (kde#438525)
  * DialogButtonBox: remove unnecessary lines
  * DialogButtonBox: Set standard icons for standard buttons
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Bind default font of Label (kde#438436)
  * kirigami-integration: use default font size for smallText on Windows
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Bump required CMake version to 3.16
  * User HoverHandler instead of MouseArea
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * Draw icon in QQStyleItem
  * [CheckBox] Rewrite to be nearly identical to RadioButton (kde#435934)
  * [RadioButton] Correct typo
  * Add failing test case to illustrate Bug 435934
  * Keep context menu above other popups, use dismiss() (kde#428631)
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * Respect highlighted property (kde#384989)
  * Fix bad default window size of tabbar test
  * Fix size of toolbuttons
  * [DialogButtonBox] Improve implicit size behavior
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Changes since 5.79.0:
  * Use more standard duration values
  * Respect the animation speed setting for menu open/close animation
  * [RoundButton] Rework the contentItem, improve background accuracy
  * Spinbox: Update value during editing (kde#433066)
  * Remove TODOs for Qt 5.7
  * [Label] Remove unnecessary code
  * Use new custom event handling to trigger color sync in Platform theme
  * Use QQuickWindow::setTextRenderType() for the default text rendering type
  * Update Kirigami platform theme to new upstream API
  * [radiobutton] Fix focus indicator
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * [combobox] Fix touchpad scroll speed (kde#400258)
  * qw can be null
  * Support QQuickWidget (kde#428737)
  * allow drag window from empty areas
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Remove ifdefs, we require Qt 5.14 now
  * Update org.kde.desktop/Dialog.qml
  * Draw ScrollView using Frame instead of Edit (kde#429601)
* Mon Dec  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * button: rely on down, not pressed for styling
  * Reduce the size of round buttons on mobile
  * Remove debugging leftover
  * fix mobile scrollbar in RTL mode
  * fix progressbar in RTL mode
  * fix RTL display for RangeSlider
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * Fix ToolBar contentWidth binding loop
  * Reference shortcut label directly by id instead of implicitly
  * ComboBox.contentItem must be a QQuickTextInput to fix autocomplete (kde#425865)
  * Simplify conditional clauses in Connections
  * Fix Connections warning on ComboBox
  * Add support for qrc icons to StyleItem (kde#427449)
  * Properly indicate focus state of ToolButton
  * Add TextFieldContextMenu for right click context menus on TextField and TextArea
  * Set background color to ComboBox's ScrollView
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * Also use highlight text color when checkDelegate is highlighted (kde#427022)
  * Respect scrollbar click to jump to position setting (kde#412685)
  * Don't inherit colors in desktop toolbar style by default
  * Remove obsolete license text for LGPL-2.0-only
  * Relicense file to LGPL-2.0-or-later
  * Use header colors only for header toolbars
  * Move color set declaration to a place where it can be overridden
  * Use Header colors for Desktop style ToolBar
  * add the missing isItem property necessary for trees
  * move the dbus connection in the singleton
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Fix StandardKey shortcut sequences in MenuItem showing as numbers
  * Don't use parent height/width for implicit ToolSeparator sizing (kde#425949)
  * Only use "focus" style for non-flat toolbuttons on press
  * Add top and bottom padding to ToolSeparator
  * Make ToolSeparator respect topPadding and bottomPadding values
  * Make MenuSeparator use background's calculated height not implicitheight
  * Fix width of ToolSeparator
  * Fix toolbuttons with menus using newer Breeze
  * Remove obsolete COPYING files
  * Draw the entire CheckBox control via the QStyle
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use "raised" style for non-flat toolbuttons
  * Only reserve space for the icon in toolbutton if we actually have an icon
  * Support showing a menu arrow on tool buttons
  * Use camelcase include. (scripted)
  * Really fix menu separator height on high DPI
  * Update Mainpage.dox
  * Set height of MenuSeparator properly (kde#423653)
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Set selectByMouse to true for SpinBox
  * Fix menu icons becoming blurry with some font sizes (kde#423236)
  * Prevent delegates and scrollbar overlapping in combobox popups
  * Fix Slider vertical implicitWidth and a binding loop
  * Make ToolTips more consistent with Breeze widget style tooltips
  * Set editable to true by default for SpinBox
  * Fix Connections warnings in Menu.qml
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Add ToolSeparator styling
  * Remove "pressed" from CheckIndicator "on" state (kde#421695)
  * support the Header group
  * Implement smallFont in Kirigami plugin
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * Detect QQC2 version at build time with actual detection.
  * [ComboBox] Use transparent dimmer
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * QQC2-Desktop-Style: Convert license headers to SPDX expressions
  * [Dialog] Use `ShadowedRectangle`
  * Fix sizing of CheckBox and RadioButton (kde#418447)
  * Use `ShadowedRectangle`
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * ScrollView: Use scrollbar height as bottom padding, not width
- Drop 0001-ScrollView-Use-scrollbar-height-as-bottom-padding-no.patch
* Mon Feb 10 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch 0001-ScrollView-Use-scrollbar-height-as-bottom-padding-no.patch
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * Remove scrollbar related workarounds from list delegates
  * [TabBar] Remove frame
  * Add active, link, visited, negative, neutral and positive background colors
  * fix paddings
  * use hasTransientTouchInput
  * always round x and y
  * support mobile mode scrollbar
  * ScrollView: Do not overlay scrollbars over contents
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * [ToolTip] Round position
  * Update size hint when font changes
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Fix typo in name of installed CMake Config: Deskop->Desktop
  * Make it compile against qt5.14 without deprecated method
  * [TabBar] Use window color instead of button color (kde#413311)
  * bind enabled properties to the view enabled
  * [ToolTip] Base timeout on text length
  * [ComboBox] Don't dim Popup
  * [ComboBox] Don't indicate focus when popup is open
  * [ComboBox] Follow focusPolicy
* Thu Nov  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Make sure the required libqt5-qtquickcontrols2 package is usable (kde#413829)
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Do not assign combobox currentIndex as it breaks binding.
  * docs: fix typo te -> the
  * Fix warning when we're not hovering a Control
  * Listen to the application style changing
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Fix several build system errors
  * Fix typo
  * take margins from qstyle
  * [QQC2 Desktop Style] Port away from deprecated methods in Qt 5.14
  * [Tab] Fix sizing (kde#409390)
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Prevent dragging QQC2 ComboBox contents outside menu
  * metainfo.yaml: set fancy name, auto-name from cmake project() is not nice
  * metainfo.yaml: remove bogus note about library to link to
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Fix broken guard that prevents styling sliders with negative values
  * Slow down the busy indicator's rotation speed
  * Fix "Type error" when creating a TextField with focus: true
  * [ComboBox] Set close policy to close on click outside instead of only outside parent (kde#408950)
  * [SpinBox] Set renderType (kde#409888)
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
- Drop patch to support Qt 5.9:
  * 0001-Fix-MobileTextActionsToolBar.qml-with-Qt-5.9.patch
- Drop patch for Leap 42.3 which is EOL:
  * fix-build-with-gcc48.patch
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Remove Qt 5.11 ifdef since we require that version now
  * MobileTextActionsToolBar: fix runtime warnings when controlRoot isn't set yet (kde#408719)
  * Show shortcut in menu item when specified (kde#405541)
  * Add MenuSeparator
  * Fix ToolButton remaining in a pressed state after press
  * [ToolButton] Pass custom icon size to StyleItem
  * honor visibility policy (kde#407014)
- Refreshed patches:
  * 0001-Fix-MobileTextActionsToolBar.qml-with-Qt-5.9.patch
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Remove DefaultListItemBackground and MenuItem animation
  * [QQC2 Slider Style] Fix wrong handle positioning when initial value is 1 (kde#405471)
  * guard minimum and maximum for sliders
  * ScrollBar: Make it work as a horizontal scroll bar as well (kde#390351)
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Avoid nesting Controls in TextField (kde#406851)
  * make the mobile text toolbar appear only on press
  * [TabBar] Update height when TabButtons are added dynamically
  * refer to the proper id
  * use the new Kirigami.WheelHandler
  * Support custom icon size for ToolButton
  * It compile fine without foreach
  Refreshed patches:
  * 0001-Fix-MobileTextActionsToolBar.qml-with-Qt-5.9.patch
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * the plasma desktop style supports icon coloring
  * [SpinBox] Improve mouse wheel behavior
  * add a bit of padding in ToolBars
  * fix RoundButton icons
  * scrollbar based padding on all delegates
  * look for a scrollview to take its scrollbar for margins
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Use PointingHand when hovering links in Label
  * Respect the display property of buttons
  * clicking on empty areas behaves like pgup/pgdown (kde#402578)
  * Support icon on ComboBox
  * support text positioning api
  * Support icons from local files in buttons
  * Use the correct cursor when hovering over the editable part of a spinbox
* Fri Feb 15 2019 alarrosa@suse.com
- Add 0001-Fix-MobileTextActionsToolBar.qml-with-Qt-5.9.patch (by Fabian Vogt)
  to fix an issue with Qt 5.9
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Fix combobox initial sizing (kde#403736)
  * Set combobox popups to be modal (kde#403403)
  * Tab bar test
  * partly revert 4f00b0cabc1230fdf
  * Word-wrap long tooltips (kde#396385)
  * ComboBox: fix default delegate
  * Fake mousehover whilst combobox is open
  * Set CombooBox QStyleOptionState == On rather than Sunken to match qwidgets
  * Fix ComboBox
  * Always draw the tooltip on top of everything else
  * Support a tooltip on a MouseArea
  * Minor: Use {} for initializing flags
  * Minor: Use nullptr
  * do not force text display for ToolButton
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Fix warning
  * Fix menu item width when the delegate is overriden (kde#401792)
  * Fix warnings
  * Rotate busy indicator clockwise
  * same behavior as Kirigami ScrollablePage
  * force checkboxes/radios to be square
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * consistent sizing of item compared to QWidgets
  * emit activated
  * same behavior as qwidgets comboboxes
  * fix Menu sizing
  * default values for ToolTip
  * proper line widths
  * make sure flickables are pixelAligned
  * Fix compilation
  * Support for QGuiApplication-based apps (kde#396287)
  * touchscreen text controls
  * Size according to specified icon width and height
  * Honor flat property of buttons
  * Remove qt include prefix
  * Fix issue where there's only one element on the menu
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * No code changes since 5.51.0
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * small default padding when there is a background
  * Make it compile with "KDEFrameworkCompilerSettings"
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * None
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Improve sizing of menus (kde#396841)
  * Remove double comparison
  * Port away from string-based connects
  * check for valid icon
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * no pixel values in checkindicator
  * own sizehit for sliders
  * use RadioIndicator for everybody
  * Don't overflow around popups
  * on Qt<5.11 the control palette is completely ignored
  * import kirigami 2.4
  * anchor button background
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Use pallet property only when using qtquickcontrols 2.4
  * work with Qt<5.10
  * add missing import
  * fix height of tabbar
  * Use Control.palette
  * --warnings
  * [RadioButton] Rename "control" to "controlRoot"
  * Don't set explicit spacing on RadioButton/CheckBox
  * [FocusRect] Use manual placement instead of anchors
  * import focusrect
  * import FocusRect
  * It turns out the flickable in a scrollview is the contentItem
  * Use override
  * Show focus rect when CheckBox or RadioButton are focused
  * hacky fix to scrollview detection
  * don't reparent the flickable to the mousearea
  * Add test file for ScrollView { TextArea {} }
  * [TabBar] Switch tabs with mouse wheel
  * Fix warning
  * Control must not have children (kde#394134)
  * constrain scroll (kde#393992)
- Dropped patches, now upstream:
  * control-must-not-have-children.patch
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * export layout paddings from qstyle, start from Control
  * [ComboBox] Fix mouse wheel handling
  * make the mousearea not interfere with controls
  * fix acceptableInput
  * remove useless debug
  * Fix warning
- Add upstream patch to fix control panel layouts (kde#394134):
  * control-must-not-have-children.patch
* Mon Apr 16 2018 wbauer@tmo.at
- Add fix-build-with-gcc48.patch to make it compile with gcc 4.8 on
  Leap 42.3
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * fix rendering when disabled
  * better layout
  * experimental support for auto mnemonics
  * We depend against 5.8.0
  * Make sure we are taking into account hte size of the element when styling
  * Fix font rendering for non-HiDPI and integer scale factors (kde#391780)
  * e our way to handle shortcuts
  * fix icons colors with colorsets
  * fix icon colors for toolbuttons
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Fix syntax error in previous commit, detected by launching ruqola
  * Show a radiobutton when we are showing an exclusive control
  * fix some Qt 5.9 bugs
  * implement MenuBarItem
  * fix logic
  * implement DelayButton
  * New component: round button
  * take into account toolbar position
  * support colors for icons in buttons
  * support --reverse
  * icons in Menu fully functional
  * consistent shadows with the new breeze style
  * ame behavior as qwidget menus
  * make icons actually work
  * Some QStyles seem to not return sensible pixelmetrics here
  * first rough icons support
  * don't wrap around with mouse wheel
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * use the inactive or disabled color group when needed
  * Apply some C++11 niceties, styling consistency
  * Add BusyIndicator to the styled controls list
  * remove flicker when hovering scrollbar
  * Cache KColorScheme instances
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * simplify and don't try to block mouse events
  * if no wheel.pixelDelta, use global wheel scroll lines
  * desktop tabbars have different widths for each tab
  * ensure a non 0 size hint
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * determine QQC2 version at build time (kde#386289)
  * by default, keep the background invisible
  * add a background in ScrollView
* Tue Nov 14 2017 wbauer@tmo.at
- Fix QtQuickControls2 BuildRequires, it needs the devel package to
  build
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Improve compilation as a static plugin.
  * make the radiobutton a radiobutton
  * use qstyle to paint the Dial
  * use a ColumnLayout for menus
  * fix Dialog
  * remove invalid group property
  * Add .arcconfig
  * Fix formatting of the md file so it matches the other modules
  * behavior of combobox closer to qqc1
  * workaround for QQuickWidgets
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Too many to list here
* Sat Aug 19 2017 fabian@ritter-vogt.de
- Initial packaging
